isIdentity property
bool
get
isIdentity
Whether model and rendered offsets line up one to one.
Implementation
bool get isIdentity => flatLength == modelLength;
Whether model and rendered offsets line up one to one.
bool get isIdentity => flatLength == modelLength;