addMarkCommand top-level constant
Marks the selection with the identifier in the payload.
Implementation
const LexicalCommand<String> addMarkCommand = LexicalCommand('ADD_MARK');
Marks the selection with the identifier in the payload.
const LexicalCommand<String> addMarkCommand = LexicalCommand('ADD_MARK');