BlockCaret class
A caret to paint over a block's text.
- Annotations
Constructors
- BlockCaret({required int offset, required Color color, double width = 2, double opacity = 1})
-
Paints a caret at flat
offset,widthwide, incolor.const
Properties
- color → Color
-
Caret colour.
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- offset → int
-
Flat text offset the caret sits at.
final
- opacity → double
-
Blink opacity. Animating this repaints without relayout.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- width → double
-
Caret width in logical pixels.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override